#
# spec file for package liborcus
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname liborcus-0_13-0
Name:           liborcus
Version:        0.13.4
Release:        lp150.1.1
Summary:        Spreadsheet file processing library
License:        MPL-2.0
Group:          Productivity/Publishing/Word
Url:            https://gitlab.com/orcus/orcus/
Source:         http://kohei.us/files/orcus/src/%{name}-%{version}.tar.xz
BuildRequires:  coreutils
BuildRequires:  gcc-c++
BuildRequires:  libstdc++-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-xml
BuildRequires:  pkgconfig(libixion-0.13)
BuildRequires:  pkgconfig(mdds-1.2)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_date_time-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_iostreams-devel
BuildRequires:  libboost_program_options-devel
%else
BuildRequires:  boost-devel
%endif

%package -n %{libname}
Summary:        Spreadsheet file processing library
Group:          System/Libraries

%description -n %{libname}
Standalone file import filter library for spreadsheet documents. Currently
under development are ODS, XLSX and CSV import filters.

%description
Standalone file import filter library for spreadsheet documents. Currently
under development are ODS, XLSX and CSV import filters.

%package devel
Summary:        Spreadsheet file processing library
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       pkgconfig(zlib)

%description devel
Standalone file import filter library for spreadsheet documents. Currently
under development are ODS, XLSX and CSV import filters.

%package tools
Summary:        Spreadsheet file processing library
Group:          Productivity/Publishing/Word
Requires:       %{libname} = %{version}

%description tools
Tools to work with various xml streams.

%package -n python3-%{name}
Summary:        Python bindings for liborcus
# Renamed in 15.0
Group:          Productivity/Publishing/Word
Provides:       %{name}-python3 = %{version}

%description -n python3-%{name}
Python 3 bindings for %{name}.

%prep
%setup -q

%build
%configure \
	--disable-silent-rules \
	--disable-static \
	--disable-debug \
	--disable-werror \
	--docdir=%{_docdir}/%{name}
make %{?_smp_mflags}

%check
make check %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license LICENSE
%{_libdir}/*.so.*

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files tools
%{_bindir}/*

%files -n python3-%{name}
%dir %{python3_sitelib}/orcus/
%{python3_sitelib}/orcus/__init__.py
%{python3_sitelib}/orcus/json.py
%{python3_sitelib}/orcus/xlsx.py
%{python3_sitearch}/_orcus.so
%{python3_sitearch}/_orcus_json.so

%changelog
* Tue Feb 27 2018 tchvatal@suse.com
- Version updat eto 0.13.4:
  * Various false positive fixes in detection of xml files
* Thu Feb 15 2018 tchvatal@suse.com
- Version update to 0.13.3:
  * Various improvements in 2003 XML imports
- Rename name-python3 to python3-name to match other python modules
* Tue Jan 30 2018 tchvatal@suse.com
- Version update to 0.13.2:
  * Various small fixes
  * Improvements in Excel 2003 XML import iflter
* Fri Jan  5 2018 tchvatal@suse.com
- Fix python-xml dep to properly state python3-xml
* Thu Dec 14 2017 tchvatal@suse.com
- Switch license to MPL-2.0
* Wed Nov 29 2017 tchvatal@suse.com
- Update to 0.13.1:
  * Required by libreoffice 6.0
  * Fixes many crashers
  * Speedup improvements
  * More features for xslx importer
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sat Dec  3 2016 tchvatal@suse.com
- Version update to 0.12.1 as required by lo 5.3
* Wed May 25 2016 tchvatal@suse.com
- Version update to 0.11.2:
  * Fix build with mdds 1.2
  * few small fixes
* Wed May 25 2016 dimstar@opensuse.org
- Changes from version 0.11.1:
  + Fix for OSX build inside LibreOffice.
  + Boost.Filesystem is needed uncoditionally.
* Thu May 12 2016 tchvatal@suse.com
- Fix libixion -> liborcus typo
* Thu May  5 2016 tchvatal@suse.com
- Coflict with liborcus-0_10-0
* Tue Mar  8 2016 fstrba@suse.com
- Change package name to correspond to the soname  of the
  libraries provided.
* Mon Mar  7 2016 tchvatal@suse.com
- Version update to 0.11.0:
  * Use mdds 1.0
  * Use ixion 0.11
  * Use python3 instead of python2
* Mon Dec 21 2015 tchvatal@suse.com
- Version update to 0.9.2:
  * Various bugfixes and update for libreoffice 5.1
* Tue Mar 24 2015 tchvatal@suse.com
- Version bump to 0.7.1:
  * Various boost bugfixes and update for new ixion
- Obsoleted patch:
  * liborcus-boost-1.56.patch
* Mon Oct 27 2014 dmitry_r@opensuse.org
- Fix build with boost-1.56
  * liborcus-boost-1.56.patch
* Mon May 26 2014 fstrba@suse.com
- Upgrade to upstream version 0.7.0
- Remove unneeded upstreamed patches:
  * liborcus-more-lib64.patch
  * liborcus-0.5.1-linking.patch
  * liborcus-0.5.1-mdds.patch
  * liborcus-0.5.1-oldnamespace.patch
- Use pkgconfig BuildRequires wherever it is possible
* Sat Jan 25 2014 tchvatal@suse.com
- Clean with spec-cleaner and Verbosify the output.
* Mon Jan  6 2014 matz@suse.com
- Add aarch64 and ppc64le to list of 64bit archs for boost_system
  detection.
  Added patches:
  * liborcus-more-lib64.patch
* Tue Nov 12 2013 jengelh@inai.de
- Correct description not to mention an N-gram text categorizer
* Thu Aug  1 2013 tchvatal@suse.com
- Version bump to 0.5.1:
  * More fixes around streaming
  * Various boost fixes
  * Improvements required for libreoffice-4.1.
- Use full download url for tarball
- Drop libzip-devel requirement
- Add patch for new mdds liborcus-0.5.1-mdds.patch
- Add patch for SLE11 gcc liborcus-0.5.1-oldnamespace.patch
- Add patch for newest boost liborcus-0.5.1-linking.patch
- Drop deprecated patch boost-configure.patch
* Sun Jun 16 2013 schwab@suse.de
- boost-configure.patch: fix boost configure check
* Fri May 31 2013 tchvatal@suse.com
- Fix building with boost-1.52 and newer.
* Wed Feb  6 2013 pmladek@suse.com
- Add libzip-devel and zlib-devel into Requires of the devel package;
  they are needed for linking against liborcus
* Tue Jan  8 2013 tchvatal@suse.com
- Rename package and sort it out for acceptance to factory.
* Tue Dec 18 2012 tchvatal@suse.com
- Build gnumeric filters as libreoffice check for them.
  * cleanup the spec a bit.
* Wed Nov 28 2012 kyoshida@suse.com
- Official 0.3.0 package.
* Sat Nov 10 2012 kyoshida@suse.com
- Updated snapshot from the latest master branch.
* Fri Oct  5 2012 kyoshida@suse.com
- Latest development snapshot from the master branch.
* Tue Oct  2 2012 kyoshida@suse.com
- Latest development snapshot from the master branch.
* Wed Sep 26 2012 kyoshida@suse.com
- Remove the obsolete package and spec.
* Wed Sep 26 2012 kyoshida@suse.com
- Add new package and spec from the latest master branch.
* Thu Sep  6 2012 kyoshida@suse.com
- Updated the package with all sorts of fixes.
* Thu Aug 30 2012 kyoshida@suse.com
- Updated the package.  It now supports --disable-libzip.
* Tue Jul 31 2012 kyoshida@suse.com
- Modified spec file to keep rpmlint happy.
* Tue Jul 31 2012 kyoshida@suse.com
- Added initial spec file.
